import QtQuick 1.0

// This example illustrates expanding a list item to show a more detailed view.

Rectangle {
    id: page

    x:0
    y:0
    z:1000
    width: parent.width
    height: parent.height

    color: "black"

    function isUnlocked(scores__, needScores__){
        if (needScores__===0) {return false}
        if (scores__<=needScores__) {return true} else {return false}
    }

    // A simple rounded rectangle for the background
    Image {
        id: backgroundImage
        x:-250-selectLevelListView.contentX/3
        width: 2500
        height: parent.height
        source: "MEDIA/GFX/levelSelectBackground.png"
    }

    UnlockMenu{
        id: unlockLevelMenu;
        visible: false;
        z: 1000
    }

    Text{
        id: scorePanel
        x: 500
        y: 10
        z: 100
        font.pixelSize: 24
        color: "black"
        text: "Total score: "+gameStatistic.score
        opacity: 1.0
    }

    Rectangle{
        id: menuButton
        x: gameScreen.width-70
        y: gameScreen.height-50
        z: 100
        width: 60
        height: 40
        opacity: 0.85
        radius: 5

        Text{
            x: 12
            y: 6
            text: "EXIT"
            font.pixelSize: 20
            color: "white"
            z: parent.z+2
        }

        Gradient {
            id: gradientStandart
            GradientStop { position: 0.0; color: "#707070" }
            GradientStop { position: 0.2; color: "#606060" }
            GradientStop { position: 0.9;color: "#303030" }
            GradientStop { position: 1.0; color: "#202020" }
        }

        Gradient {
            id: gradientPressed
            GradientStop { position: 0.0; color: "#202020" }
            GradientStop { position: 0.2;color: "#303030" }
            GradientStop { position: 0.9; color: "#606060" }
            GradientStop { position: 1.0; color: "#707070" }
        }

        border.color: "black"
        gradient: gradientStandart

        MouseArea{
            anchors.fill:parent
            anchors.bottom: parent.bottom
            width:parent.width
            height: parent.height

            onPressed: menuButton.gradient=gradientPressed
            onReleased: menuButton.gradient=gradientStandart
            onClicked: {
                Qt.quit()
            }
        }
    }


    ListModel {
        id: levelModel

        ListElement {
            levelNumber: 0
            name: "New York"
            icon: "MEDIA/GFX/backgroundPreview.png"
            needScores: 0
        }
        ListElement {
            levelNumber: 1
            name: "Golden Gate Bridge"
            icon: "MEDIA/GFX/background2Preview.png"
            needScores: 3000
        }
        ListElement {
            levelNumber: 2
            name: "Paris"
            icon: "MEDIA/GFX/background3Preview.png"
            needScores: 3500
        }
        ListElement {
            levelNumber: 3
            name: "Moscow"
            icon: "MEDIA/GFX/background4Preview.png"
            needScores: 4000
        }
        ListElement {
            levelNumber: 4
            name: "Chernobil"
            icon: "MEDIA/GFX/background5Preview.png"
            needScores: 4500
        }
        ListElement {
            levelNumber: 5
            name: "Egypt"
            icon: "MEDIA/GFX/background6Preview.png"
            needScores: 5000
        }
        ListElement {
            levelNumber: 6
            name: "China"
            icon: "MEDIA/GFX/background7Preview.png"
            needScores: 6000
        }
    }

    Component {
        id: levelDelegate

        Item {
            id: level

            // Create a property to contain the visibility of the details.
            // We can bind multiple element's opacity to this one property,
            // rather than having a "PropertyChanges" line for each element we
            // want to fade.
            property real detailsOpacity : 0

            y: 30
            width: 480
            height: 440

            Text {
                id: headerRow
                y:30
                anchors.horizontalCenter: parent.horizontalCenter
                text: ((gameStatistic.levelUnlocked[levelNumber*3])?(name):("Locked"))
                font.bold: true;
                font.pixelSize: 24
                color: "black"
            }

            Rectangle {
                id: previewImage
                x:70; y:100
                width: 340; height: 190
                radius:10
                clip:true
                border.width: 2
                color:"black"
                smooth: true
                Image {
                    id: levelIcon
                    width: parent.width; height: parent.height
                    opacity: 0.5
                    source: (gameStatistic.levelUnlocked[levelNumber*3])?icon:"MEDIA/GFX/lockedPreview.png"
                }

                MouseArea{
                    anchors.fill: parent
                    onClicked:{
                        if ((!gameStatistic.levelUnlocked[levelNumber*3])&&((levelNumber>0)?(gameStatistic.levelUnlocked[(levelNumber-1)*3]):(true))){
                            if (gameStatistic.score>=needScores){
                                unlockLevelMenu.scoresToUnlock=needScores
                                unlockLevelMenu.levelToUnlock=levelNumber
                                unlockLevelMenu.visible=true
                            }
                        }
                    }
                }
            }

            Text{
                y:300
                visible: (!gameStatistic.levelUnlocked[levelNumber*3])&&((levelNumber>0)?(gameStatistic.levelUnlocked[(levelNumber-1)*3]):(true))
                anchors.horizontalCenter: parent.horizontalCenter
                font.bold: true;
                font.pixelSize: 24
                color: (gameStatistic.score>=needScores)?"#281801":"#000000"
                text: "Unlock cost: "+needScores
            }

            Gradient {
                id: gradientStandart
                GradientStop { position: 0.0; color: "#707070" }
                GradientStop { position: 0.2; color: "#606060" }
                GradientStop { position: 0.9;color: "#303030" }
                GradientStop { position: 1.0; color: "#202020" }
            }


            Rectangle {
                x:30; y:240
                width: 115; height: 115;
                radius: 20
                clip:true
                border.width: 2
                border.color:"black"
                gradient: gradientStandart
                smooth: true
                opacity: 0.7
                visible: (gameStatistic.levelUnlocked[levelNumber*3])

                Image {
                    id: levelIconDuck1
                    anchors.fill: parent
                    source: (gameStatistic.levelUnlocked[levelNumber*3])?"MEDIA/GFX/oneDuckIcon.png":"MEDIA/GFX/lockedIcon.png"
                }

                Image {
                    z: 100
                    anchors.fill: parent
                    source: "MEDIA/GFX/passed.png"
                    visible: gameStatistic.levelPassed[levelNumber*3+1-1]
                }

                MouseArea{
                    anchors.fill: parent
                    onClicked:{
                        if (gameStatistic.levelUnlocked[levelNumber*3]){
                            gameStatistic.level=levelNumber
                            gameStatistic.mode=1
                            gameStatistic.levelAndMode=gameStatistic.level*3+gameStatistic.mode-1
                            startNewLevel()
                        }
                    }
                }

            }

            Rectangle {
                x:165; y:225
                width: 145; height: 145;
                radius: 20
                clip:true
                border.width: 2
                border.color:"black"
                gradient: gradientStandart
                smooth: true
                opacity: 0.7
                visible: (gameStatistic.levelUnlocked[levelNumber*3])

                Image {
                    id: levelIconDuck2
                    anchors.fill: parent
                    source: (gameStatistic.levelUnlocked[levelNumber*3+1])?"MEDIA/GFX/twoDuckIcon.png":"MEDIA/GFX/lockedIcon.png"
                }

                Image {
                    z: 100
                    anchors.fill: parent
                    source: "MEDIA/GFX/passed.png"
                    visible: gameStatistic.levelPassed[levelNumber*3+2-1]
                }

                MouseArea{
                    anchors.fill: parent
                    onClicked:{
                        if (gameStatistic.levelUnlocked[levelNumber*3+1]){
                            gameStatistic.level=levelNumber
                            gameStatistic.mode=2
                            gameStatistic.levelAndMode=gameStatistic.level*3+gameStatistic.mode-1
                            startNewLevel()
                        }
                    }
                }
            }

            Rectangle {
                x: 335; y: 240
                width: 125; height: 125;
                radius: 20
                clip:true
                border.width: 2
                border.color:"black"
                gradient: gradientStandart
                smooth: true
                opacity: 0.7
                visible: (gameStatistic.levelUnlocked[levelNumber*3])

                Image {
                    id: levelIconDuck3
                    anchors.fill: parent
                    source: (gameStatistic.levelUnlocked[levelNumber*3+2])?"MEDIA/GFX/threeDuckIcon.png":"MEDIA/GFX/lockedIcon.png"
                }

                Image {
                    z: 100
                    anchors.fill: parent
                    source: "MEDIA/GFX/passed.png"
                    visible: gameStatistic.levelPassed[levelNumber*3+3-1]
                }

                MouseArea{
                    anchors.fill: parent
                    onClicked:{
                        if (gameStatistic.levelUnlocked[levelNumber*3+2]){
                            gameStatistic.level=levelNumber
                            gameStatistic.mode=3
                            gameStatistic.levelAndMode=gameStatistic.level*3+gameStatistic.mode-1
                            startNewLevel()
                        }
                    }
                }
            }

        }
    }


    // The actual list
    ListView {
        id: selectLevelListView
        anchors.fill: parent
        model: levelModel
        delegate: levelDelegate
        orientation: ListView.Horizontal

    }

    function startNewLevel(){
        if (gameScreen.state=="LEVEL1"){
            newYorkTheme.stop()
        } else if (gameScreen.state=="LEVEL2"){
            goldenGateTheme.stop()
        } else if (gameScreen.state=="LEVEL3"){
            parisTheme.stop()
        } else if (gameScreen.state=="LEVEL4"){
            moscowTheme.stop()
        }  else if (gameScreen.state=="LEVEL5"){
            chernobilTheme.stop()
        }  else if (gameScreen.state=="LEVEL6"){
            egyptTheme.stop()
        } else if (gameScreen.state=="LEVEL7"){
            chinaTheme.stop()
        }

        if (gameStatistic.level==0) {gameScreen.state="LEVEL1"} else
            if (gameStatistic.level==1) {gameScreen.state="LEVEL2"} else
                if (gameStatistic.level==2) {gameScreen.state="LEVEL3"} else
                    if (gameStatistic.level==3) {gameScreen.state="LEVEL4"} else
                        if (gameStatistic.level==4) {gameScreen.state="LEVEL5"} else
                            if (gameStatistic.level==5) {gameScreen.state="LEVEL6"} else{gameScreen.state="LEVEL7"}

        if (gameScreen.state=="LEVEL1"){
            grass.source="MEDIA/GFX/grass0.png"
        } else if (gameScreen.state=="LEVEL2"){
            flash.visible=false
            grass.source="MEDIA/GFX/grass02.png"
        } else if (gameScreen.state=="LEVEL3"){
            flash.visible=false
            grass.source="MEDIA/GFX/grass03.png"
        } else if (gameScreen.state=="LEVEL4"){
            flash.visible=true
            grass.source="MEDIA/GFX/grass04.png"
        }  else if (gameScreen.state=="LEVEL5"){
            flash.visible=true
            grass.source="MEDIA/GFX/grass05.png"
        }  else if (gameScreen.state=="LEVEL6"){
            flash.visible=false
            grass.source="MEDIA/GFX/grass06.png"
        } else if (gameScreen.state=="LEVEL7"){
            flash.visible=true
            grass.source="MEDIA/GFX/grass07.png"
        }


        if (gameScreen.state=="LEVEL1"){
            newYorkTheme.play()
        } else if (gameScreen.state=="LEVEL2"){
            goldenGateTheme.play()
        } else if (gameScreen.state=="LEVEL3"){
            parisTheme.play()
        } else if (gameScreen.state=="LEVEL4"){
            moscowTheme.play()
        }  else if (gameScreen.state=="LEVEL5"){
            chernobilTheme.play()
        }  else if (gameScreen.state=="LEVEL6"){
            egyptTheme.play()
        } else if (gameScreen.state=="LEVEL7"){
            chinaTheme.play()
        }

        gameStatistic.level++
        gameStatistic.total=10*gameStatistic.mode+gameStatistic.level
        gameStatistic.ducksTotal=gameStatistic.total
        gameStatistic.kill=0
        gameStatistic.miss=0
        gameStatistic.bullet=Math.round(gameStatistic.total+(gameStatistic.total/100)*30)
        gameStatistic.multiplier=1
        gameStatistic.series=0
        gameStatistic.levelScore=0

        multiplierText.visible=false
        multiplierText.font.pixelSize=20
        multiplierText.x=400
        multiplierText.y=5
        multiplierText.up=true

        dog.currentFrame=-1
        dog.animationSpeed=120
        dog.speed=6
        dog.x=1
        dog.y=310
        dog.prevX=0
        dog.prevY=310
        dog.targetX= 200
        dog.targetY= 310
        dog.z=100
        dog.state="START_LEVEL"

        blackDuck.x=10+Math.random()*(gameScreen.width-10)
        blackDuck.y=360
        blackDuck.prevX=398
        blackDuck.prevY=362
        blackDuck.targetX=10+Math.random()*800
        blackDuck.targetY=10+Math.random()*350
        blackDuck.z=3
        blackDuck.lifeTime=0
        blackDuck.flyAway=false
        blackDuck.state="TOP"

        if (blackDuck.animationSpeed>20) blackDuck.animationSpeed=80-gameStatistic.level*10;
        if (blackDuck.speed<8)blackDuck.speed=4+gameStatistic.level
        if (blackDuck.speed<8)blackDuck.epsilon=10+gameStatistic.level

        brownDuck.x=10+Math.random()*(gameScreen.width-10)
        brownDuck.y=360
        brownDuck.prevX=398
        brownDuck.prevY=362
        brownDuck.targetX=10+Math.random()*800
        brownDuck.targetY=10+Math.random()*350
        brownDuck.z=5
        brownDuck.lifeTime=0
        brownDuck.flyAway=false
        brownDuck.state="TOP"

        if (brownDuck.animationSpeed>20) brownDuck.animationSpeed=80-gameStatistic.level*10;
        if (brownDuck.speed<8) brownDuck.speed=4+gameStatistic.level
        if (brownDuck.speed<8) brownDuck.epsilon=10+gameStatistic.level

        greenDuck.x=10+Math.random()*(gameScreen.width-10)
        greenDuck.y=360
        greenDuck.prevX=398
        greenDuck.prevY=362
        greenDuck.targetX=10+Math.random()*800
        greenDuck.targetY=10+Math.random()*350
        greenDuck.z=5
        greenDuck.lifeTime=0
        greenDuck.flyAway=false
        greenDuck.state="TOP"

        if (greenDuck.animationSpeed>20) greenDuck.animationSpeed=80-gameStatistic.level*10;
        if (greenDuck.speed<8) greenDuck.speed=4+gameStatistic.level
        if (greenDuck.speed<8) greenDuck.epsilon=10+gameStatistic.level

        blackDuckNeeded=true
        brownDuckNeeded=true
        greenDuckNeeded=true

        gameStatistic.visible=false

        blackDuckTimer.stop()
        brownDuckTimer.stop()
        greenDuckTimer.stop()
        dogTimer.start()
        chienMarche.play()

        mainPage.paused=false
        mainPage.gameStarted=true
        selectLevelMenu.visible=false
    }
}
