import QtQuick 1.0
import FileIO 1.0

Rectangle {
    id: mainMenuPanel

    property string playButtonImage: "MEDIA/GFX/menu/startNewGameButton.png"

    width: 360
    height: ((gameStatistic.oldGameExist)&&(startMenu.playButtonImage=="MEDIA/GFX/menu/startNewGameButton.png"))?250:200

    x:parent.width/2-width/2
    y:parent.height/2-height/2
    z:100

    opacity: 0.9
    color: "#404040"
    radius: 10
    visible: true
    border.color: "black"

    Gradient {
        id: gradientStandart
        GradientStop { position: 0.0; color: "#707070" }
        GradientStop { position: 0.2; color: "#606060" }
        GradientStop { position: 0.9;color: "#303030" }
        GradientStop { position: 1.0; color: "#202020" }
    }

    Gradient {
        id: gradientPressed
        GradientStop { position: 0.0; color: "#202020" }
        GradientStop { position: 0.2;color: "#303030" }
        GradientStop { position: 0.9; color: "#606060" }
        GradientStop { position: 1.0; color: "#707070" }
    }


    Rectangle{
        id: resumeButton
        x: parent.width/2-width/2
        y: 10
        z: parent.z+1
        width: 330
        height: 55
        visible: ((gameStatistic.oldGameExist)&&(startMenu.playButtonImage=="MEDIA/GFX/menu/startNewGameButton.png"))
        radius: 10

        Image{
            source: "MEDIA/GFX/menu/resumeButton.png"
            anchors.centerIn: parent
            z: parent.z+2
        }

        border.color: "black"
        gradient: gradientStandart

        MouseArea{
            anchors.fill:parent
            anchors.bottom: parent.bottom
            width:parent.width
            height: parent.height

            onPressed: resumeButton.gradient=gradientPressed
            onReleased: resumeButton.gradient=gradientStandart
            onClicked: {
                loadProgress();

                fakeSoundEffect1.stop()
                fakeSoundEffect2.stop()
                shotSound.stop()
                fireSound.stop()
                duckFlightSound.stop()
                duckDeadSound.stop()
                canardSol.stop()
                chienRamasse.stop()
                chienMarche.stop()
                chienSaute.stop()
                chienCry.stop()
                gameOverTheme.stop()

                startMenu.visible=false
                menuButton.visible=true
                selectLevelMenu.visible=true
            }
        }
    }


    Rectangle{
        id: playButton
        x: parent.width/2-width/2
        y: ((gameStatistic.oldGameExist)&&(startMenu.playButtonImage=="MEDIA/GFX/menu/startNewGameButton.png"))?70:10
        z: parent.z+1
        width: 330
        height: 55
        visible: parent.visible
        radius: 10

        Image{
            source: playButtonImage
            anchors.centerIn: parent
            z: parent.z+2
        }

        border.color: "black"
        gradient: gradientStandart

        MouseArea{
            anchors.fill:parent
            anchors.bottom: parent.bottom
            width:parent.width
            height: parent.height

            onPressed: playButton.gradient=gradientPressed
            onReleased: playButton.gradient=gradientStandart
            onClicked: {
                if (startMenu.playButtonImage=="MEDIA/GFX/menu/startNewGameButton.png") {
                    startMenu.visible=false
                    menuButton.visible=true
                    selectLevelMenu.visible=true
                } else {
                    mainPage.paused=false
                    menuButton.visible=true
                    startMenu.visible=false

                    if (gameScreen.state=="LEVEL1"){
                        newYorkTheme.play()
                    } else if (gameScreen.state=="LEVEL2"){
                        goldenGateTheme.play()
                    } else if (gameScreen.state=="LEVEL3"){
                        parisTheme.play()
                    } else if (gameScreen.state=="LEVEL4"){
                        moscowTheme.play()
                    }  else if (gameScreen.state=="LEVEL5"){
                        chernobilTheme.play()
                    }  else if (gameScreen.state=="LEVEL6"){
                        egyptTheme.play()
                    } else if (gameScreen.state=="LEVEL7"){
                        chinaTheme.play()
                    }
                }
            }
        }
    }

    Rectangle{
        id: aboutButton
        x: parent.width/2-width/2
        y: playButton.y+60
        z: parent.z+1
        width: 330
        height: 55
        visible: parent.visible
        radius: 10

        Image{
            source: "MEDIA/GFX/menu/aboutButton.png"
            anchors.centerIn: parent
            z: parent.z+2
        }

        border.color: "black"
        gradient: gradientStandart

        MouseArea{
            anchors.fill:parent
            anchors.bottom: parent.bottom
            width:parent.width
            height: parent.height

            onPressed: aboutButton.gradient=gradientPressed
            onReleased: aboutButton.gradient=gradientStandart
            onClicked: {
                startMenu.visible=false
                menuButton.visible=false
                aboutMenu.visible=true
            }
        }
    }

    Rectangle{
        id: exitButton
        x: parent.width/2-width/2
        y: playButton.y+120
        z: parent.z+1
        width: 330
        height: 55
        visible: parent.visible
        radius: 10

        Image{
            source: "MEDIA/GFX/menu/exitButton.png"
            anchors.centerIn: parent
            z: parent.z+2
        }

        border.color: "black"
        gradient: gradientStandart

        MouseArea{
            anchors.fill:parent
            anchors.bottom: parent.bottom
            width:parent.width
            height: parent.height

            onPressed: exitButton.gradient=gradientPressed
            onReleased: exitButton.gradient=gradientStandart
            onClicked: {
                gameOverTheme.stop()
                newYorkTheme.stop()
                goldenGateTheme.stop()
                parisTheme.stop()
                moscowTheme.stop()
                chernobilTheme.stop()
                egyptTheme.stop()
                chinaTheme.stop()
                Qt.quit()
            }
        }
    }

    FileIO {
        id: confFile
        source: iniFilePath
        onError: console.log(msg)
    }

    function loadProgress(){
        confFile.openFile();
        console.log(confFile.readLine());
        gameStatistic.score=confFile.readLine();
        confFile.readLine();
        console.log(gameStatistic.score);

        for (var i=0; i<21; i++){
            var levelUnlocked=(confFile.readLine()=="true");
            var levelPassed=(confFile.readLine()=="true");
            var levelHighScores=confFile.readLine();

            var temp = gameStatistic.levelPassed
            temp[i]=levelPassed
            gameStatistic.levelPassed=temp

            var temp2 = gameStatistic.levelHighScores
            temp2[i]=levelHighScores
            gameStatistic.levelHighScores=temp2

            var temp3 = gameStatistic.levelUnlocked
            temp3[i]=levelUnlocked
            gameStatistic.levelUnlocked=temp3
            console.log(gameStatistic.levelUnlocked[i]);
        }

        confFile.closeFile();
    }

}
